import tkinter as tk

class TruckApp:
    def __init__(self, master):
        self.master = master
        self.master.title("תנועת משאית")
        
        # הגדרת גודל החלון
        self.width = 600
        self.height = 400
        self.master.geometry(f"{self.width}x{self.height}")
        self.master.resizable(False, False)

        # יצירת קנבס
        self.canvas = tk.Canvas(self.master, width=self.width, height=self.height, bg="white")
        self.canvas.pack(fill="both", expand=True)

        # משתנים למיקום המשאית - נתחיל את המשאית באמצע המסך
        self.truck_x = self.width // 2
        self.truck_y = self.height // 2

        # גדלים של חלקי המשאית
        self.truck_body_width = 120
        self.truck_body_height = 60
        self.truck_cabin_width = 40
        self.truck_cabin_height = 40

        self.inner_rect_margin = 10
        self.arrow_box_size = 20

        # מרחק הזזה לכל לחיצה
        self.move_step = 10

        # צבעים
        self.arrow_normal_color = "#FFCC99"
        self.arrow_highlight_color = "#FFFF99"  # צבע הארה (צהוב בהיר)

        # יצירת המשאית
        self.create_truck()
        # יצירת החיצים בתוך גוף המשאית (מלבן + טקסט)
        self.create_arrows()

        # חלקי המשאית כדי להזיז את כולם יחד
        # נוסיף גם את הטקסט של החיצים כדי שיזוזו עם המשאית
        self.truck_parts = [
            self.truck_body, self.truck_cabin,
            self.wheel_body, self.wheel_cabin,
            self.arrow_up_rect, self.arrow_down_rect,
            self.arrow_left_rect, self.arrow_right_rect,
            self.arrow_up_text, self.arrow_down_text,
            self.arrow_left_text, self.arrow_right_text
        ]

        # קישור מקשי מקלדת
        # נשתמש ב-KeyPress ו-KeyRelease כדי לייצר הארה כל עוד מקש לחוץ
        self.master.bind("<KeyPress-Up>", lambda e: self.press_key_arrow("up"))
        self.master.bind("<KeyRelease-Up>", lambda e: self.release_key_arrow("up"))
        self.master.bind("<KeyPress-Down>", lambda e: self.press_key_arrow("down"))
        self.master.bind("<KeyRelease-Down>", lambda e: self.release_key_arrow("down"))
        self.master.bind("<KeyPress-Left>", lambda e: self.press_key_arrow("left"))
        self.master.bind("<KeyRelease-Left>", lambda e: self.release_key_arrow("left"))
        self.master.bind("<KeyPress-Right>", lambda e: self.press_key_arrow("right"))
        self.master.bind("<KeyRelease-Right>", lambda e: self.release_key_arrow("right"))

        # קישור לחיצות עכבר על החיצים שבמשאית
        # בעת לחיצה עם העכבר נבצע הארה והזזה, ובעת שחרור עכבר נסיר הארה
        self.canvas.tag_bind(self.arrow_up_rect, "<ButtonPress-1>", lambda e: self.press_mouse_arrow("up"))
        self.canvas.tag_bind(self.arrow_up_rect, "<ButtonRelease-1>", lambda e: self.release_mouse_arrow("up"))
        self.canvas.tag_bind(self.arrow_down_rect, "<ButtonPress-1>", lambda e: self.press_mouse_arrow("down"))
        self.canvas.tag_bind(self.arrow_down_rect, "<ButtonRelease-1>", lambda e: self.release_mouse_arrow("down"))
        self.canvas.tag_bind(self.arrow_left_rect, "<ButtonPress-1>", lambda e: self.press_mouse_arrow("left"))
        self.canvas.tag_bind(self.arrow_left_rect, "<ButtonRelease-1>", lambda e: self.release_mouse_arrow("left"))
        self.canvas.tag_bind(self.arrow_right_rect, "<ButtonPress-1>", lambda e: self.press_mouse_arrow("right"))
        self.canvas.tag_bind(self.arrow_right_rect, "<ButtonRelease-1>", lambda e: self.release_mouse_arrow("right"))

        # נוסיף גם אפשרות ללחוץ על הטקסט של החיצים, שיהיה נוח:
        self.canvas.tag_bind(self.arrow_up_text, "<ButtonPress-1>", lambda e: self.press_mouse_arrow("up"))
        self.canvas.tag_bind(self.arrow_up_text, "<ButtonRelease-1>", lambda e: self.release_mouse_arrow("up"))
        self.canvas.tag_bind(self.arrow_down_text, "<ButtonPress-1>", lambda e: self.press_mouse_arrow("down"))
        self.canvas.tag_bind(self.arrow_down_text, "<ButtonRelease-1>", lambda e: self.release_mouse_arrow("down"))
        self.canvas.tag_bind(self.arrow_left_text, "<ButtonPress-1>", lambda e: self.press_mouse_arrow("left"))
        self.canvas.tag_bind(self.arrow_left_text, "<ButtonRelease-1>", lambda e: self.release_mouse_arrow("left"))
        self.canvas.tag_bind(self.arrow_right_text, "<ButtonPress-1>", lambda e: self.press_mouse_arrow("right"))
        self.canvas.tag_bind(self.arrow_right_text, "<ButtonRelease-1>", lambda e: self.release_mouse_arrow("right"))

    def create_truck(self):
        # נצייר את גוף המשאית
        body_left = self.truck_x - self.truck_body_width//2
        body_right = self.truck_x + self.truck_body_width//2
        body_top = self.truck_y - self.truck_body_height//2
        body_bottom = self.truck_y + self.truck_body_height//2

        # תא הנהג בצד ימין
        cabin_left = body_right
        cabin_right = cabin_left + self.truck_cabin_width
        cabin_top = self.truck_y - self.truck_cabin_height//2
        cabin_bottom = self.truck_y + self.truck_cabin_height//2

        self.truck_body = self.canvas.create_rectangle(body_left, body_top, body_right, body_bottom,
                                                       fill="#FF9966", outline="#000000", width=3)
        self.truck_cabin = self.canvas.create_rectangle(cabin_left, cabin_top, cabin_right, cabin_bottom,
                                                        fill="black", outline="black")

        # גלגלים (עיגולים שחורים)
        wheel_radius = 10
        wheel_y = body_bottom + wheel_radius
        wheel_body_center_x = self.truck_x - 30
        wheel_cabin_center_x = cabin_left + (self.truck_cabin_width // 2)

        self.wheel_body = self.canvas.create_oval(wheel_body_center_x - wheel_radius, wheel_y - wheel_radius,
                                                  wheel_body_center_x + wheel_radius, wheel_y + wheel_radius,
                                                  fill="black", outline="")
        self.wheel_cabin = self.canvas.create_oval(wheel_cabin_center_x - wheel_radius, wheel_y - wheel_radius,
                                                   wheel_cabin_center_x + wheel_radius, wheel_y + wheel_radius,
                                                   fill="black", outline="")

    def create_arrows(self):
        # ניצור את החיצים בתוך המשאית
        coords = self.canvas.coords(self.truck_body)
        body_left, body_top, body_right, body_bottom = coords

        inner_left = body_left + self.inner_rect_margin
        inner_right = body_right - self.inner_rect_margin
        inner_top = body_top + self.inner_rect_margin
        inner_bottom = body_bottom - self.inner_rect_margin

        box = self.arrow_box_size
        center_x = (inner_left + inner_right) / 2
        center_y = (inner_top + inner_bottom) / 2

        # מיקום החיצים:
        #      [UP]
        # [LEFT][DOWN][RIGHT]

        # חץ למעלה
        up_x1 = center_x - box/2
        up_y1 = center_y - box*1.5
        up_x2 = up_x1 + box
        up_y2 = up_y1 + box
        self.arrow_up_rect = self.canvas.create_rectangle(up_x1, up_y1, up_x2, up_y2,
                                                          fill=self.arrow_normal_color, outline="black")
        self.arrow_up_text = self.canvas.create_text((up_x1+up_x2)/2, (up_y1+up_y2)/2, text="↑", font=("Arial", 10, "bold"))

        # חץ למטה
        down_x1 = center_x - box/2
        down_y1 = center_y + box*0.5
        down_x2 = down_x1 + box
        down_y2 = down_y1 + box
        self.arrow_down_rect = self.canvas.create_rectangle(down_x1, down_y1, down_x2, down_y2,
                                                            fill=self.arrow_normal_color, outline="black")
        self.arrow_down_text = self.canvas.create_text((down_x1+down_x2)/2, (down_y1+down_y2)/2, text="↓", font=("Arial", 10, "bold"))

        # חץ שמאלה
        left_x1 = center_x - box*1.5
        left_y1 = center_y + box*0.5
        left_x2 = left_x1 + box
        left_y2 = left_y1 + box
        self.arrow_left_rect = self.canvas.create_rectangle(left_x1, left_y1, left_x2, left_y2,
                                                            fill=self.arrow_normal_color, outline="black")
        self.arrow_left_text = self.canvas.create_text((left_x1+left_x2)/2, (left_y1+left_y2)/2, text="←", font=("Arial", 10, "bold"))

        # חץ ימינה
        right_x1 = center_x + box*0.5
        right_y1 = center_y + box*0.5
        right_x2 = right_x1 + box
        right_y2 = right_y1 + box
        self.arrow_right_rect = self.canvas.create_rectangle(right_x1, right_y1, right_x2, right_y2,
                                                             fill=self.arrow_normal_color, outline="black")
        self.arrow_right_text = self.canvas.create_text((right_x1+right_x2)/2, (right_y1+right_y2)/2, text="→", font=("Arial", 10, "bold"))

    def move_truck(self, direction):
        dx, dy = 0, 0
        if direction == "up":
            dy = -self.move_step
        elif direction == "down":
            dy = self.move_step
        elif direction == "left":
            dx = -self.move_step
        elif direction == "right":
            dx = self.move_step

        # נבדוק את גבולות המשאית לפני הזזה
        bbox = self.canvas.bbox(*self.truck_parts)
        if bbox is None:
            return

        new_left = bbox[0] + dx
        new_top = bbox[1] + dy
        new_right = bbox[2] + dx
        new_bottom = bbox[3] + dy

        # בדיקה מול גבולות החלון
        if new_left < 0 or new_top < 0 or new_right > self.width or new_bottom > self.height:
            # אם ייצא מהגבולות - לא זזים
            return

        # הזזה של כל חלקי המשאית
        for obj in self.truck_parts:
            self.canvas.move(obj, dx, dy)

        # עדכון מיקום המשאית
        self.truck_x += dx
        self.truck_y += dy

    def highlight_arrow(self, direction):
        # הארה של החץ המתאים
        if direction == "up":
            self.canvas.itemconfig(self.arrow_up_rect, fill=self.arrow_highlight_color)
        elif direction == "down":
            self.canvas.itemconfig(self.arrow_down_rect, fill=self.arrow_highlight_color)
        elif direction == "left":
            self.canvas.itemconfig(self.arrow_left_rect, fill=self.arrow_highlight_color)
        elif direction == "right":
            self.canvas.itemconfig(self.arrow_right_rect, fill=self.arrow_highlight_color)

    def unhighlight_arrow(self, direction):
        # חזרה לצבע המקורי של החץ המתאים
        if direction == "up":
            self.canvas.itemconfig(self.arrow_up_rect, fill=self.arrow_normal_color)
        elif direction == "down":
            self.canvas.itemconfig(self.arrow_down_rect, fill=self.arrow_normal_color)
        elif direction == "left":
            self.canvas.itemconfig(self.arrow_left_rect, fill=self.arrow_normal_color)
        elif direction == "right":
            self.canvas.itemconfig(self.arrow_right_rect, fill=self.arrow_normal_color)

    # טיפול באירועי מקלדת
    def press_key_arrow(self, direction):
        self.highlight_arrow(direction)
        self.move_truck(direction)

    def release_key_arrow(self, direction):
        self.unhighlight_arrow(direction)

    # טיפול באירועי עכבר
    def press_mouse_arrow(self, direction):
        self.highlight_arrow(direction)
        self.move_truck(direction)
        # ההארה תשאר כל עוד כפתור העכבר לחוץ

    def release_mouse_arrow(self, direction):
        self.unhighlight_arrow(direction)


if __name__ == "__main__":
    root = tk.Tk()
    app = TruckApp(root)
    root.mainloop()
